@@ -70,7 +70,7 @@ You can use Droplet actions to perform tasks on a Droplet, such as rebooting, re
 	cmdDropletActionGet.Example = `The following example retrieves information about an action, with the ID ` + "`" + `1978716488` + "`" + `, performed on a Droplet with the ID ` + "`" + `386734086` + "`" + `: doctl compute droplet-action get 1978716488 --action-id 386734086`
 
 	cmdDropletActionEnableBackups := CmdBuilder(cmd, RunDropletActionEnableBackups,
-		"enable-backups <droplet-id>", "Enable backups on a Droplet", `Enables backups on a Droplet. This automatically creates and stores a disk image of the Droplet at weekly intervals.`, Writer,
+		"enable-backups <droplet-id>", "Enable backups on a Droplet", `Enables backups on a Droplet. This automatically creates and stores a disk image of the Droplet. By default, backups happen daily.`, Writer,
 		displayerType(&displayers.Action{}))
 	AddBoolFlag(cmdDropletActionEnableBackups, doctl.ArgCommandWait, "", false, "Wait for action to complete")
 	cmdDropletActionEnableBackups.Example = `The following example enables backups on a Droplet with the ID ` + "`" + `386734086` + "`" + `: doctl compute droplet-action enable-backups 386734086`
@@ -167,7 +167,7 @@ This command automatically powers off the Droplet before resizing it.`
 		"resize <droplet-id>", "Resize a Droplet", dropletResizeDesc, Writer,
 		displayerType(&displayers.Action{}))
 	AddBoolFlag(cmdDropletActionResize, doctl.ArgResizeDisk, "", false, "Resize the Droplet's disk size in addition to its RAM and CPUs")
-	AddStringFlag(cmdDropletActionResize, doctl.ArgSizeSlug, "", "", "A slug indicating the new size for the Droplet, for example `s-2vcpu-2gb`. Run `doctl compute size list` for a list of valid sizes.", requiredOpt())
+	AddStringFlag(cmdDropletActionResize, doctl.ArgSizeSlug, "", "", "A `slug` indicating the new size for the Droplet, for example `s-2vcpu-2gb`. Run `doctl compute size list` for a list of valid sizes.", requiredOpt())
 	AddBoolFlag(cmdDropletActionResize, doctl.ArgCommandWait, "", false, "Instruct the terminal to wait for the action to complete before returning access to the user")
 	cmdDropletActionResize.Example = `The following example resizes a Droplet with the ID ` + "`" + `386734086` + "`" + ` to a Droplet with two CPUs, two GiB of RAM, and 60 GBs of disk space. The 60 GBs of disk space is the defined amount for the ` + "`" + `s-2vcpu-2gb` + "`" + ` plan: doctl compute droplet-action resize 386734086 --size s-2vcpu-2gb --resize-disk=true`
 
